summaryrefslogtreecommitdiffhomepage
diff options
context:
space:
mode:
authorGuido Günther <agx@sigxcpu.org>2014-07-24 19:43:25 +0200
committerGuido Günther <agx@sigxcpu.org>2014-07-24 19:43:25 +0200
commitfb45b7ec0e6eb24899f7a77a82642c9665ac93b1 (patch)
tree1de17f62b5d133c2bbe0518551d7f9558a68f893
parent7f6b72e039efa5e2c3517b9336f9b29b4cb65c71 (diff)
Fix typos
-rw-r--r--gbp/pkg/__init__.py8
1 files changed, 4 insertions, 4 deletions
diff --git a/gbp/pkg/__init__.py b/gbp/pkg/__init__.py
index 66638380..52d34691 100644
--- a/gbp/pkg/__init__.py
+++ b/gbp/pkg/__init__.py
@@ -35,9 +35,9 @@ compressor_aliases = { 'bz2' : 'bzip2',
'gz' : 'gzip', }
# Supported archive formats
-arhive_formats = [ 'tar', 'zip' ]
+archive_formats = [ 'tar', 'zip' ]
-# Map combined file extensions to arhive and compression format
+# Map combined file extensions to archive and compression format
archive_ext_aliases = { 'tgz' : ('tar', 'gzip'),
'tbz2' : ('tar', 'bzip2'),
'tlz' : ('tar', 'lzma'),
@@ -79,7 +79,7 @@ def parse_archive_filename(filename):
if split[-1] in archive_ext_aliases:
base_name = ".".join(split[:-1])
(archive_fmt, compression) = archive_ext_aliases[split[-1]]
- elif split[-1] in arhive_formats:
+ elif split[-1] in archive_formats:
base_name = ".".join(split[:-1])
(archive_fmt, compression) = (split[-1], None)
else:
@@ -87,7 +87,7 @@ def parse_archive_filename(filename):
if o[1] == split[-1]:
base_name = ".".join(split[:-1])
compression = c
- if len(split) > 2 and split[-2] in arhive_formats:
+ if len(split) > 2 and split[-2] in archive_formats:
base_name = ".".join(split[:-2])
archive_fmt = split[-2]